@@ -29,7 +29,7 @@ setGeneric("trim", function(object, ...){standardGeneric("trim")})
 #' @rdname trim-method
 setMethod("trim", "TermDocumentMatrix", function(object, termsToKeep=NULL, termsToDrop=NULL, docsToKeep=NULL, docsToDrop=NULL, verbose=TRUE){
   .rmBlank <- function(mat, verbose=TRUE){
-    if (verbose==TRUE) message("... removing empty rows")
+    .message("removing empty rows", verbose = verbose)
     matTmp <- as.sparseMatrix(mat)
     matTmp <- matTmp[which(rowSums(matTmp) > 0),]
     mat <- as.simple_triplet_matrix(matTmp)
@@ -57,42 +57,10 @@ setMethod("trim", "DocumentTermMatrix", function(object, ...){
 })
 
 
-#' trim dispersion object
-#' 
-#' Drop unwanted columns in a dispersion object, and merge columns by either explicitly stating the columns,
-#' or providing a regex. If merge$old is length 1, it is assumed that a regex is provided
-#' 
-#' @param object a crosstab object to be adjusted
-#' @param drop defaults to NULL, or a character vector giving columns to be dropped 
-#' @param merge a list giving columns to be merged or exactly one string with a regex (see examples)
-#' @return a modified crosstab object
-#' @docType methods
-#' @rdname dispersion-class
-#' @exportMethod trim
-#' @docType methods
-setMethod("trim", "dispersion", function(object, drop=NULL, merge=list(old=c(), new=c())){
-  if (!is.null(drop)){
-    object <- .crosstabDrop(x=object, filter=drop, what="drop")
-  }
-  if (!all(sapply(merge, is.null))){
-    if (length(merge$new) != 1) warning("check length of character vectors in merge-list (needs to be 1)")
-    if (length(merge$old) == 2){
-      object <- .crosstabMergeCols(
-        object,
-        colnameOld1=merge$old[1], colnameOld2=merge$old[2],
-        colnameNew=merge$new[1]
-      )
-    } else if (length(merge$old == 1 )){
-      object <- .crosstabMergeColsRegex(object, regex=merge$old[1], colname.new=merge$new[1])
-    } else {
-      warning("length of merge$old not valid")
-    }
-  }
-})
 
 
 #' @rdname context-class
-setMethod("trim", "context", function(object, sAttribute = NULL, verbose = TRUE, progress = TRUE){
+setMethod("trim", "context", function(object, sAttribute = NULL, positivelist = NULL, pAttribute = pAttributes(object), regex = FALSE, stoplist = NULL, verbose = TRUE, progress = TRUE){
   
   if(!is.null(sAttribute)){
     stopifnot(length(sAttribute) == 1)
@@ -105,7 +73,7 @@ setMethod("trim", "context", function(object, sAttribute = NULL, verbose = TRUE,
     position <- 0 # work around to make data.table syntax pass R CMD check
     struc <- 0 # work around to make data.table syntax pass R CMD check
     
-    if (verbose) message("... checking boundaries of regions")
+    .message("checking boundaries of regions", verbose = verbose)
     if (progress) pb <- txtProgressBar(min = 1, max = object@count, style = 3)
     .checkBoundary <- function(.SD, .GRP){
       if (progress) setTxtProgressBar(pb, value = .GRP)
@@ -117,23 +85,43 @@ setMethod("trim", "context", function(object, sAttribute = NULL, verbose = TRUE,
     setnames(object@cpos, old = "struc", new = sAttrCol)
   }
   
+  if (!is.null(positivelist)){
+    .message("filtering by positivelist", verbose = verbose)
+    before <- length(unique(object@cpos[["hit_no"]]))
+    positivelistIds <- .token2id(corpus = object@corpus, pAttribute = pAttribute, token = positivelist, regex = regex)
+    .keepPositives <- function(.SD){
+      pAttr <- paste(pAttribute[1], "id", sep = "_")
+      positives <- which(.SD[[pAttr]] %in% positivelistIds)
+      positives <- positives[ -which(.SD[["position"]] == 0) ] # exclude node
+      if (any(positives)) return( .SD ) else return( NULL )
+    }
+    object@cpos <- object@cpos[, .keepPositives(.SD), by = "hit_no", with = TRUE]
+    after <- length(unique(object@cpos[["hit_no"]]))
+    .message("number of hits droped due to positivelist:", before - after, verbose = verbose)
+    if (nrow(object@cpos) == 0) {
+      warning("no remaining hits after applying positivelist, returning NULL object")
+      return( invisible(NULL) )
+    }
+  }
+  
+  if (!is.null(stoplist)){
+    .message("applying stoplist", verbose = verbose)
+    before <- length(unique(object@cpos[["hit_no"]]))
+    stoplistIds <- .token2id(corpus = object@corpus, pAttribute = pAttribute, token = stoplist, regex = regex)
+    .dropNegatives <- function(.SD){
+      pAttr <- paste(pAttribute[1], "id", sep = "_")
+      negatives <- which(.SD[[pAttr]] %in% stoplistIds)
+      negatives <- negatives[ -which(.SD[["position"]] == 0) ] # exclude node
+      if (any(negatives)) return( NULL ) else return( .SD ) # this is the only difference
+    }
+    object@cpos <- object@cpos[, .dropNegatives(.SD), by = "hit_no", with = TRUE]
+    after <- length(unique(object@cpos[["hit_no"]]))
+    .message("number of hits droped due to stoplist:", before - after, verbose = verbose)
+    if (nrow(object@cpos) == 0) {
+      warning("no remaining hits after applying stoplist, returning NULL object")
+      return( NULL )
+    }
+  }
+  
   object
 })
-
-# #' @rdname cooccurrences-class
-# setMethod("trim", "cooccurrences", function(object, mc=TRUE, reshape=FALSE, by=NULL, ...){
-#   if (reshape == TRUE) object <- .reshapeCooccurrences(object, mc=mc)
-#   if (is.null(by) == FALSE){
-#     if (class(by) %in% c("compCooccurrences", "cooccurrencesReshaped")){
-#       bidirectional <- strsplit(rownames(by@stat), "<->")
-#       fromTo <- c(
-#         sapply(bidirectional, function(pair) paste(pair[1], "->", pair[2], sep="")),
-#         sapply(bidirectional, function(pair) paste(pair[2], "->", pair[1], sep=""))
-#       ) 
-#       object@stat <- object@stat[which(rownames(object@stat) %in% fromTo),]
-#     }
-#   }
-#   callNextMethod()
-# })
-# 
-
